@@ -1,10 +1,8 @@
-from typing import List, Dict, Union, Optional, Any, Tuple, NewType
+from typing import List, Dict, Union, Optional, Any, Tuple
 from collections import OrderedDict
 import json
 
 
-
-
 # Custom JSON Encoder
 class CustomJSONEncoder(json.JSONEncoder):
     def default(self, obj):
@@ -65,8 +63,6 @@ class SWML(Action):
                              "generate a SWML string from a SWMLResponse object.")
 
 
-
-
 class Say(Action):
     def __init__(self, message: str):
         self.say = message
