@@ -2,9 +2,29 @@ from .swml_instructions import *
 import json
 import yaml
 
+
 # Constants
 SUPPORTED_FORMATS = ['json', 'yaml']
 
+
+class CustomDumper(yaml.Dumper):
+    pass
+
+
+def represent_str(dumper, data):
+    # Check if the string contains newlines
+    if '\n' in data:
+        # Use block literal style for multiline strings
+        return dumper.represent_scalar('tag:yaml.org,2002:str', data, style='|')
+    else:
+        # Use plain style for other strings
+        return dumper.represent_scalar('tag:yaml.org,2002:str', data, style='"')
+
+
+# Register the custom representer for strings
+CustomDumper.add_representer(str, represent_str)
+
+
 class Section:
     def __init__(self):
         self.instructions: List[Union[Instruction, dict]] = []
@@ -30,8 +50,8 @@ class Section:
                 ringback=None, timeout=None, max_duration=None, answer_on_bridge=None, call_state_url=None,
                 call_state_events=None, result=None, serial_parallel=None, serial=None, parallel=None, to_number=None):
         self.add_instruction(Connect(from_number, headers, codecs, webrtc_media, session_timeout, ringback, timeout,
-                                    max_duration, answer_on_bridge, call_state_url, call_state_events, result,
-                                    serial_parallel, serial, parallel, to_number))
+                                     max_duration, answer_on_bridge, call_state_url, call_state_events, result,
+                                     serial_parallel, serial, parallel, to_number))
 
     def denoise(self):
         self.add_instruction(Denoise())
@@ -55,8 +75,8 @@ class Section:
                terminators=None, digit_timeout=None, initial_timeout=None, speech_timeout=None, speech_end_timeout=None,
                speech_language=None, speech_hints=None, result=None):
         self.add_instruction(Prompt(play, volume, say_voice, say_language, say_gender, max_digits, terminators,
-                                   digit_timeout, initial_timeout, speech_timeout, speech_end_timeout, speech_language,
-                                   speech_hints, result))
+                                    digit_timeout, initial_timeout, speech_timeout, speech_end_timeout, speech_language,
+                                    speech_hints, result))
 
     def receive_fax(self):
         self.add_instruction(ReceiveFax())
@@ -64,12 +84,12 @@ class Section:
     def record(self, stereo=None, format_=None, direction=None, terminators=None, beep=None, input_sensitivity=None,
                initial_timeout=None, end_silence_timeout=None):
         self.add_instruction(Record(stereo, format_, direction, terminators, beep, input_sensitivity, initial_timeout,
-                                   end_silence_timeout))
+                                    end_silence_timeout))
 
     def record_call(self, control_id=None, stereo=None, format_=None, direction=None, terminators=None, beep=None,
                     input_sensitivity=None, initial_timeout=None, end_silence_timeout=None):
         self.add_instruction(RecordCall(control_id, stereo, format_, direction, terminators, beep, input_sensitivity,
-                                       initial_timeout, end_silence_timeout))
+                                        initial_timeout, end_silence_timeout))
 
     def request(self, url, method, headers=None, body=None, timeout=None, connect_timeout=None, save_variables=False):
         self.add_instruction(Request(url, method, headers, body, timeout, connect_timeout, save_variables))
@@ -84,7 +104,16 @@ class Section:
         self.add_instruction(SendFax(document, header_info, identity))
 
     def send_sms(self, to_number, from_number, body, media=None, region=None, tags=None):
-        self.add_instruction(SendSMS(to_number, from_number, body, media, region, tags))
+
+        params = {
+            "to_number": f"{to_number}",
+            "from_number": f"{from_number}",
+            "body": body,
+            "media": media,
+            "region": region,
+            "tags": tags
+        }
+        self.add_instruction(SendSMS(**params))
 
     def set(self, variables):
         self.add_instruction(Set(variables))
@@ -137,4 +166,5 @@ class SWMLResponse:
         if format_ == "json":
             return json.dumps({"sections": sections_dict}, sort_keys=False)
         else:
-            return yaml.dump({"sections": sections_dict}, sort_keys=False)
+            return yaml.dump({"sections": sections_dict}, sort_keys=False, default_flow_style=False,
+                             Dumper=CustomDumper)
